@@ -54,6 +54,7 @@ from .core import (
     UTCTime,
     UTF8String,
     VisibleString,
+    VOID,
 )
 from .keys import PublicKeyInfo
 from .util import int_to_bytes, int_from_bytes, inet_ntop, inet_pton
@@ -981,6 +982,9 @@ class Name(Choice):
 
         return self.chosen.hashable
 
+    def __len__(self):
+        return len(self.chosen)
+
     def __ne__(self, other):
         return not self == other
 
@@ -2221,6 +2225,8 @@ class Certificate(Sequence):
 
         for distribution_point in crl_distribution_points:
             distribution_point_name = distribution_point['distribution_point']
+            if distribution_point_name is VOID:
+                continue
             # RFC 5280 indicates conforming CA should not use the relative form
             if distribution_point_name.name == 'name_relative_to_crl_issuer':
                 continue
